function [K,distCoeffs,err]=AprilCalib(varargin)
% A matlab wrapper class for camera calibration
% [K,distCoeffs,err]=AprilCalib; %default Tag36h11 and video 0
% [K,distCoeffs,err]=AprilCalib(tagfamilyName);
% [K,distCoeffs,err]=AprilCalib(tagfamilyName,videoDevice);
%
% author: Chen Feng <simbaforrest at gmail dot com>
Apriltag4Matlab.install; %ensure jar is installed

%default input args
tagfamilyName='Tag36h11';
videoDevice=0;
switch nargin
  case 1
    tagfamilyName=varargin{1};
  case 2
    [tagfamilyName, videoDevice]=deal(varargin{:});
end
fprintf('AprilCalib to be started with:\n');
fprintf('\tTagfamily: %s\n',tagfamilyName);
fprintf('\tVideoDevice: %d\n', videoDevice);

try
  tf = javaObject(['april.tag.',tagfamilyName]);
  ac = matlab.apriltag.AprilCalib(tf);
  rawRet = ac.run(videoDevice);
catch err
  error(err.message);
end

if isempty(rawRet) || ~rawRet.valid()
  K=[];
  distCoeffs=[];
  err=[];
  fprintf('AprilCalib cancelled or failed.');
else
  K=rawRet.K;
  distCoeffs=rawRet.distCoeffs;
  err=rawRet.err;
  fprintf('AprilCalib results:');
  matlab.apriltag.AprilCalib.print(rawRet);
end
end